@@ -12,11 +12,10 @@
  */
 package freeguide.common.gui;
 
-import freeguide.common.gui.FGDialog;
-
 import freeguide.common.lib.fgspecific.Application;
 import freeguide.common.lib.fgspecific.data.TVChannelsSet;
 import freeguide.common.lib.fgspecific.selection.Favourite;
+import freeguide.common.lib.general.StringHelper;
 import freeguide.common.lib.general.Time;
 import freeguide.common.lib.general.Utils;
 
@@ -45,10 +44,12 @@ import javax.swing.JDialog;
  * DOCUMENT ME!
  *
  * @author $author$
- * @version $Revision: 1315 $
+ * @version $Revision: 1602 $
  */
 public class FavouriteEditorDialog extends FGDialog
 {
+    protected static final String SPACE_RE_FROM = "\\s+";
+    protected static final String SPACE_RE_TO = " ";
     private final static SimpleDateFormat dayOfWeekFormat =
         new SimpleDateFormat( "EEEE" );
     private javax.swing.JButton butCancel;
@@ -168,7 +169,7 @@ public class FavouriteEditorDialog extends FGDialog
         cmbTitle.addItem( 
             Application.getInstance(  )
                        .getLocalizedMessage( "regular_expression" ) );
-        cmbChannel.addItem( "" );
+        cmbChannel.addItem( StringHelper.EMPTY_STRING );
 
         Iterator it = allChannelsSet.getChannels(  ).iterator(  );
 
@@ -180,7 +181,7 @@ public class FavouriteEditorDialog extends FGDialog
         }
 
         Calendar cal = GregorianCalendar.getInstance(  );
-        cmbDayOfWeek.addItem( "" );
+        cmbDayOfWeek.addItem( StringHelper.EMPTY_STRING );
         cal.set( Calendar.DAY_OF_WEEK, Calendar.SUNDAY );
         cmbDayOfWeek.addItem( dayOfWeekFormat.format( cal.getTime(  ) ) );
         cal.set( Calendar.DAY_OF_WEEK, Calendar.MONDAY );
@@ -220,7 +221,7 @@ public class FavouriteEditorDialog extends FGDialog
 
             String tmp = txtTitle.getText(  );
 
-            if( tmp.equals( "" ) )
+            if( tmp.equals( StringHelper.EMPTY_STRING ) )
             {
                 favourite.setTitleString( null );
             }
@@ -240,7 +241,7 @@ public class FavouriteEditorDialog extends FGDialog
 
             String tmp = txtTitle.getText(  );
 
-            if( tmp.equals( "" ) )
+            if( tmp.equals( StringHelper.EMPTY_STRING ) )
             {
                 favourite.setTitleContains( null );
             }
@@ -256,7 +257,7 @@ public class FavouriteEditorDialog extends FGDialog
 
             String tmp = txtTitle.getText(  );
 
-            if( tmp.equals( "" ) )
+            if( tmp.equals( StringHelper.EMPTY_STRING ) )
             {
                 favourite.setTitleRegex( null );
             }
@@ -283,7 +284,7 @@ public class FavouriteEditorDialog extends FGDialog
         String tmp = txtAfter.getText(  );
 
         if( 
-            !tmp.equals( "" ) && ( tmp.length(  ) == 5 )
+            !tmp.equals( StringHelper.EMPTY_STRING ) && ( tmp.length(  ) == 5 )
                 && ( tmp.charAt( 2 ) == ':' ) )
         {
             //String hhmm = tmp.substring(0,2) + tmp.substring(3);
@@ -298,7 +299,7 @@ public class FavouriteEditorDialog extends FGDialog
         tmp = txtBefore.getText(  );
 
         if( 
-            !tmp.equals( "" ) && ( tmp.length(  ) == 5 )
+            !tmp.equals( StringHelper.EMPTY_STRING ) && ( tmp.length(  ) == 5 )
                 && ( tmp.charAt( 2 ) == ':' ) )
         {
             //String hhmm = tmp.substring(0,2) + tmp.substring(3);
@@ -312,7 +313,7 @@ public class FavouriteEditorDialog extends FGDialog
         // Set the day of the week
         tmp = (String)cmbDayOfWeek.getSelectedItem(  );
 
-        if( !tmp.equals( "" ) )
+        if( !tmp.equals( StringHelper.EMPTY_STRING ) )
         {
             Calendar cal = GregorianCalendar.getInstance(  );
 
@@ -350,22 +351,22 @@ public class FavouriteEditorDialog extends FGDialog
         String dayOfWeek = cmbDayOfWeek.getSelectedItem(  ).toString(  );
 
         // Prepare strings that will be substituted into the name template
-        String equalsString = "";
+        String equalsString = StringHelper.EMPTY_STRING;
         Object[] equalsArray = { title };
-        String containsString = "";
+        String containsString = StringHelper.EMPTY_STRING;
         Object[] containsArray = { title };
-        String regexpString = "";
+        String regexpString = StringHelper.EMPTY_STRING;
         Object[] regexpArray = { title };
-        String channelString = "";
+        String channelString = StringHelper.EMPTY_STRING;
         Object[] channelArray = { channel };
-        String afterString = "";
+        String afterString = StringHelper.EMPTY_STRING;
         Object[] afterArray = { after };
-        String beforeString = "";
+        String beforeString = StringHelper.EMPTY_STRING;
         Object[] beforeArray = { before };
-        String dayOfWeekString = "";
+        String dayOfWeekString = StringHelper.EMPTY_STRING;
         Object[] dayOfWeekArray = { dayOfWeek };
 
-        if( !title.equals( "" ) )
+        if( !title.equals( StringHelper.EMPTY_STRING ) )
         {
             if( 
                 cmbTitle.getSelectedItem(  )
@@ -395,28 +396,28 @@ public class FavouriteEditorDialog extends FGDialog
             }
         }
 
-        if( !channel.equals( "" ) )
+        if( !channel.equals( StringHelper.EMPTY_STRING ) )
         {
             channelString = Application.getInstance(  )
                                        .getLocalizedMessage( 
                     "favourite_name_channel_template", channelArray );
         }
 
-        if( !after.equals( "" ) )
+        if( !after.equals( StringHelper.EMPTY_STRING ) )
         {
             afterString = Application.getInstance(  )
                                      .getLocalizedMessage( 
                     "favourite_name_after_template", afterArray );
         }
 
-        if( !before.equals( "" ) )
+        if( !before.equals( StringHelper.EMPTY_STRING ) )
         {
             beforeString = Application.getInstance(  )
                                       .getLocalizedMessage( 
                     "favourite_name_before_template", beforeArray );
         }
 
-        if( !dayOfWeek.equals( "" ) )
+        if( !dayOfWeek.equals( StringHelper.EMPTY_STRING ) )
         {
             dayOfWeekString = Application.getInstance(  )
                                          .getLocalizedMessage( 
@@ -433,9 +434,9 @@ public class FavouriteEditorDialog extends FGDialog
             Application.getInstance(  )
                        .getLocalizedMessage( 
                 "favourite_name_template", nameArgs );
-        name = name.replaceAll( "\\s+", " " ).trim(  );
+        name = name.replaceAll( SPACE_RE_FROM, SPACE_RE_TO ).trim(  );
 
-        if( name.equals( "" ) )
+        if( name.equals( StringHelper.EMPTY_STRING ) )
         {
             name = Application.getInstance(  )
                               .getLocalizedMessage( "all_programmes" );
@@ -524,7 +525,7 @@ public class FavouriteEditorDialog extends FGDialog
         getContentPane(  ).setLayout( new java.awt.GridBagLayout(  ) );
         labTitle = new javax.swing.JLabel( 
                 Application.getInstance(  ).getLocalizedMessage( 
-                    "title_matches" ) + ":", javax.swing.SwingConstants.RIGHT );
+                    "title_matches" ) + ':', javax.swing.SwingConstants.RIGHT );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 1;
@@ -552,7 +553,7 @@ public class FavouriteEditorDialog extends FGDialog
         getContentPane(  ).add( cmbTitle, gridBagConstraints );
         labChannel = new javax.swing.JLabel( 
                 Application.getInstance(  ).getLocalizedMessage( "channel_is" )
-                + ":", javax.swing.SwingConstants.RIGHT );
+                + ':', javax.swing.SwingConstants.RIGHT );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 2;
@@ -571,7 +572,7 @@ public class FavouriteEditorDialog extends FGDialog
         getContentPane(  ).add( cmbChannel, gridBagConstraints );
         labAfter = new javax.swing.JLabel( 
                 Application.getInstance(  ).getLocalizedMessage( "on_after" )
-                + ":", javax.swing.SwingConstants.RIGHT );
+                + ':', javax.swing.SwingConstants.RIGHT );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 3;
@@ -600,7 +601,7 @@ public class FavouriteEditorDialog extends FGDialog
         getContentPane(  ).add( txtBefore, gridBagConstraints );
         labBefore = new javax.swing.JLabel( 
                 Application.getInstance(  ).getLocalizedMessage( "on_before" )
-                + ":", javax.swing.SwingConstants.RIGHT );
+                + ':', javax.swing.SwingConstants.RIGHT );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 4;
@@ -612,7 +613,6 @@ public class FavouriteEditorDialog extends FGDialog
                            .getLocalizedMessage( 
                     "you_may_leave_any_fields_blank" ),
                 javax.swing.SwingConstants.CENTER );
-        labBlankFields.setFont( new java.awt.Font( "Dialog", 0, 12 ) );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 0;
@@ -620,12 +620,10 @@ public class FavouriteEditorDialog extends FGDialog
         gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
         getContentPane(  ).add( labBlankFields, gridBagConstraints );
         labTimeFormat = new javax.swing.JLabel( 
-                "<html>"
-                + Application.getInstance(  )
-                             .getLocalizedMessage( 
-                    "times_should_be_entered_as_hhmm" ) + "</html>",
+                Application.getInstance(  )
+                           .getLocalizedMessage( 
+                    "times_should_be_entered_as_hhmm" ),
                 javax.swing.SwingConstants.LEFT );
-        labTimeFormat.setFont( new java.awt.Font( "Dialog", 0, 12 ) );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 2;
         gridBagConstraints.gridy = 3;
@@ -638,7 +636,7 @@ public class FavouriteEditorDialog extends FGDialog
         getContentPane(  ).add( labTimeFormat, gridBagConstraints );
         labDayOfWeek = new javax.swing.JLabel( 
                 Application.getInstance(  ).getLocalizedMessage( 
-                    "on_day_label" ) + ":", javax.swing.SwingConstants.RIGHT );
+                    "on_day_label" ) + ':', javax.swing.SwingConstants.RIGHT );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 6;
@@ -647,7 +645,7 @@ public class FavouriteEditorDialog extends FGDialog
         getContentPane(  ).add( labDayOfWeek, gridBagConstraints );
         labName = new javax.swing.JLabel( 
                 Application.getInstance(  ).getLocalizedMessage( "name" )
-                + ":", javax.swing.SwingConstants.RIGHT );
+                + ':', javax.swing.SwingConstants.RIGHT );
         gridBagConstraints = new java.awt.GridBagConstraints(  );
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 7;
