@@ -1,6 +1,7 @@
 package freeguide.common.plugininterfaces;
 
 import java.util.List;
+import java.util.Locale;
 import java.util.TimeZone;
 import java.util.logging.Logger;
 
@@ -52,11 +53,13 @@ public interface IApplication
 
     IMainMenu getMainMenu(  );
 
+    Locale[] getSupportedLocales(  );
+
 /**
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1311 $
+     * @version $Revision: 1600 $
      */
     public interface IMainMenu
     {
