@@ -1,7 +1,8 @@
 package freeguide.plugins.grabber.xmltv;
 
 import freeguide.common.lib.fgspecific.Application;
-import freeguide.common.lib.general.LanguageHelper;
+import freeguide.common.lib.general.FileHelper;
+import freeguide.common.lib.general.ResourceHelper;
 import freeguide.common.lib.general.StringHelper;
 import freeguide.common.lib.general.Utils;
 import freeguide.common.lib.importexport.XMLTVImport;
@@ -15,6 +16,7 @@ import freeguide.common.plugininterfaces.IProgress;
 import freeguide.common.plugininterfaces.IStoragePipe;
 
 import freeguide.plugins.program.freeguide.FreeGuide;
+import freeguide.plugins.program.freeguide.viewer.MainFrame;
 
 import org.xml.sax.SAXException;
 
@@ -27,6 +29,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 
+import java.text.MessageFormat;
+
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -48,6 +52,22 @@ import javax.xml.parsers.ParserConfigurationException;
 public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
     IModuleConfigureFromWizard
 {
+    protected static final String DIR_CONFIG = "xmltv-configs";
+    protected static final String DIR_INSTALLED = "xmltv";
+    protected static final String REPLACE_CONFIG = "%config_file%";
+    protected static final String REPLACE_XMLTV = "%xmltv_path%";
+    protected static final String SUBST_LIN = "lin";
+    protected static final String SUBST_WIN = "win";
+    protected static final String ENV_PATH = "PATH";
+    protected static final String CHANNEL_PREFIX = "xmltv/";
+    protected static final String CONFIG_KEY_SUFFIX = "cfg";
+    protected static final String RUN_KEY_SUFFIX = "run";
+    protected static final String LIN_KEY_SUFFIX = "lin";
+    protected static final String WIN_KEY_SUFFIX = "win";
+    protected static final String PACKAGE_XMLTVWIN = "other/xmltv-win/";
+    protected static final String PACKAGE_XMLTVWIN_LIST =
+        PACKAGE_XMLTVWIN + "ls-xmltv";
+
     /** DOCUMENT ME! */
     public final static int REDOWNLOAD_ALWAYS = 0;
 
@@ -60,6 +80,14 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
     // execExternal
     // ----------------------------------------------------------------------
     protected static Properties cmds;
+    protected static final String FILE_COMMANDS =
+        "resources/plugins/grabber/xmltv/commands.properties";
+    protected static final String REGION_PREFIX = "region.";
+    protected static final String GRABBER_SUFFIX = ".grabber";
+    protected static final String DISPLAY_NAME_SUFFIX = ".displayName";
+    protected static final String CHANNEL_SELECT_SUFFIX =
+        ".allowChannelsSelect";
+    protected static final String SUFFIX_FILE_CONFIG = ".conf";
 
     /** DOCUMENT ME! */
     public XMLTVConfig config = new XMLTVConfig(  );
@@ -72,39 +100,79 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
      */
     public void start(  )
     {
-        final JMenuItem menuLine = new JMenuItem(  );
-        menuLine.setText( 
-            getLocalizer(  ).getLocalizedMessage( "Menu.Tools.ChooseChannels" ) );
-        Application.getInstance(  ).getMainMenu(  ).getTools(  )
-                   .insert( menuLine, 0 );
+        final File xmltvConfigDir =
+            new File( 
+                Application.getInstance(  ).getWorkingDirectory(  ), DIR_CONFIG );
 
-        menuLine.addActionListener( 
-            new ActionListener(  )
+        //na_dd is the only module currently
+        XMLTVConfig.ModuleInfo moduleInfo =
+            (XMLTVConfig.ModuleInfo)config.modules.get( 0 );
+
+        String cmd = moduleInfo.commandToRun;
+
+        if( null == cmd )
+        {
+            cmd = getCommand( moduleInfo.moduleName, RUN_KEY_SUFFIX );
+
+            if( null == cmd )
             {
-                public void actionPerformed( ActionEvent e )
+                Application.getInstance(  ).getLogger(  )
+                           .severe( 
+                    "Command not defined for " + moduleInfo.moduleName );
+
+                return;
+            }
+        }
+
+        cmd = StringHelper.replaceAll( 
+                cmd, REPLACE_CONFIG,
+                new File( xmltvConfigDir, moduleInfo.configFileName )
+                .getAbsolutePath(  ) );
+
+        cmd = StringHelper.replaceAll( 
+                cmd, REPLACE_XMLTV,
+                new File( 
+                    Application.getInstance(  ).getWorkingDirectory(  ),
+                    DIR_INSTALLED ).getAbsolutePath(  ) );
+
+        if( checkXmltvExists( Utils.parseCommand( cmd ) ) ) //extracts xmltv from jar on Windows if needed
+        {
+            final JMenuItem menuLine =
+                ( (MainFrame)Application.getInstance(  ).getApplicationFrame(  ) )
+                .getMenuItemChooseXMLTVChannels(  );
+            menuLine.setText( i18n.getString( "Menu.Tools.ChooseChannels" ) );
+            Application.getInstance(  ).getMainMenu(  ).getTools(  )
+                       .insert( menuLine, 0 );
+
+            menuLine.addActionListener( 
+                new ActionListener(  )
                 {
-                    new Thread(  )
-                        {
-                            public void run(  )
+                    public void actionPerformed( ActionEvent e )
+                    {
+                        new Thread(  )
                             {
-                                final List modules = new ArrayList(  );
-
-                                synchronized( config.modules )
+                                public void run(  )
                                 {
-                                    modules.addAll( config.modules );
-                                }
+                                    final List modules = new ArrayList(  );
 
-                                for( int i = 0; i < modules.size(  ); i++ )
-                                {
-                                    final XMLTVConfig.ModuleInfo moduleInfo =
-                                        (XMLTVConfig.ModuleInfo)modules
-                                        .get( i );
-                                    configureChannels( moduleInfo );
+                                    synchronized( config.modules )
+                                    {
+                                        modules.addAll( config.modules );
+                                    }
+
+                                    for( int i = 0; i < modules.size(  );
+                                            i++ )
+                                    {
+                                        final XMLTVConfig.ModuleInfo moduleInfo =
+                                            (XMLTVConfig.ModuleInfo)modules.get( 
+                                                i );
+                                        configureChannels( moduleInfo );
+                                    }
                                 }
-                            }
-                        }.start(  );
-                }
-            } );
+                            }.start(  );
+                    }
+                } );
+        }
     }
 
     /**
@@ -112,6 +180,8 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
      */
     public void stop(  )
     {
+        Application.getInstance(  ).getLogger(  )
+                   .exiting( this.getClass(  ).getName(  ), "stop" );
     }
 
     /**
@@ -131,58 +201,75 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
      * @param logger DOCUMENT ME!
      * @param storage DOCUMENT ME!
      *
+     * @return DOCUMENT_ME!
+     *
      * @throws Exception DOCUMENT_ME!
      */
-    public void grabData( 
+    public boolean grabData( 
         final IProgress progress, final ILogger logger,
         final IStoragePipe storage ) throws Exception
     {
+        int code = 0;
+
         synchronized( config.modules )
         {
             for( int i = 0; i < config.modules.size(  ); i++ )
             {
                 if( Thread.interrupted(  ) )
                 {
-                    return;
+                    return true;
                 }
 
                 XMLTVConfig.ModuleInfo moduleInfo =
                     (XMLTVConfig.ModuleInfo)config.modules.get( i );
-                grabOne( storage, moduleInfo, progress, logger );
+                code = grabOne( storage, moduleInfo, progress, logger );
+
+                if( code != 0 )
+                {
+                    break;
+                }
             }
         }
+
+        return ( code == 0 ) ? true : false;
     }
 
     protected void configureChannels( final XMLTVConfig.ModuleInfo moduleInfo )
     {
-        new File( 
-            Application.getInstance(  ).getWorkingDirectory(  )
-            + "/xmltv-configs/" ).mkdirs(  );
+        final File xmltvConfigDir =
+            new File( 
+                Application.getInstance(  ).getWorkingDirectory(  ), DIR_CONFIG );
+        xmltvConfigDir.mkdirs(  );
 
         String cmd = moduleInfo.configCommandToRun;
 
         if( cmd == null )
         {
-            cmd = getCommand( moduleInfo.moduleName, "cfg" );
+            cmd = getCommand( moduleInfo.moduleName, CONFIG_KEY_SUFFIX );
         }
 
         if( cmd == null )
         {
             Application.getInstance(  ).getLogger(  )
                        .severe( 
-                "Command not defined for " + moduleInfo.moduleName );
+                MessageFormat.format( 
+                    i18n.getString( "Message.CommandNotDefined" ),
+                    moduleInfo.moduleName ) );
 
             return;
 
         }
 
         cmd = StringHelper.replaceAll( 
-                cmd, "%config_file%",
-                Application.getInstance(  ).getWorkingDirectory(  )
-                + "/xmltv-configs/" + moduleInfo.configFileName );
+                cmd, REPLACE_CONFIG,
+                new File( xmltvConfigDir, moduleInfo.configFileName )
+                .getAbsolutePath(  ) );
+
         cmd = StringHelper.replaceAll( 
-                cmd, "%xmltv_path%",
-                Application.getInstance(  ).getInstallDirectory(  ) + "/xmltv" );
+                cmd, REPLACE_XMLTV,
+                new File( 
+                    Application.getInstance(  ).getWorkingDirectory(  ),
+                    DIR_INSTALLED ).getAbsolutePath(  ) );
 
         Application.getInstance(  ).getLogger(  ).finest( 
             "Run command: " + cmd );
@@ -192,7 +279,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
                    .finest( "Result code = " + resultCode );
     }
 
-    protected static synchronized Map getCommands(  )
+    protected static synchronized Map<String, String> getCommands(  )
     {
         if( cmds == null )
         {
@@ -200,9 +287,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
             try
             {
-                cmds.load( 
-                    LanguageHelper.getUncachedStream( 
-                        "resources/plugins/grabber/xmltv/commands.properties" ) );
+                cmds.load( ResourceHelper.getUncachedStream( FILE_COMMANDS ) );
 
             }
             catch( IOException ex )
@@ -214,26 +299,50 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             }
         }
 
-        return cmds;
+        return (Map)cmds;
 
     }
 
     protected static String getCommand( 
         final String modName, final String suffix )
     {
-        return (String)getCommands(  )
-                           .get( 
-            modName + "." + suffix + "."
-            + ( Application.getInstance(  ).isUnix(  ) ? "lin" : "win" ) );
+        Map<String, String> cmds = getCommands(  );
+        String platformSuffix;
 
+        if( Application.getInstance(  ).isUnix(  ) )
+        {
+            platformSuffix = SUBST_LIN;
+        }
+        else
+        {
+            platformSuffix = SUBST_WIN;
+        }
+
+        String ans;
+        String specificKey = modName + '.' + suffix + '.' + platformSuffix;
+
+        if( cmds.containsKey( specificKey ) )
+        {
+            ans = cmds.get( specificKey );
+        }
+        else
+        {
+            String defaultKey = "default." + suffix + '.' + platformSuffix;
+            ans = cmds.get( defaultKey );
+
+            if( modName != null )
+            {
+                ans = ans.replaceAll( "%cmdname%", modName );
+            }
+        }
+
+        return ans;
     }
 
-    protected static String[] getMods( 
-        final String prefix, final String suffix )
+    protected static String[] getGrabbers(  )
     {
-        List result = new ArrayList(  );
-
-        Map cs = getCommands(  );
+        List<String> result = new ArrayList<String>(  );
+        Map<String, String> cs = getCommands(  );
 
         Iterator it = cs.keySet(  ).iterator(  );
 
@@ -241,22 +350,52 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
         {
             String key = (String)it.next(  );
 
-            if( key.startsWith( prefix ) && key.endsWith( suffix ) )
+            if( 
+                key.startsWith( REGION_PREFIX )
+                    && key.endsWith( GRABBER_SUFFIX ) )
             {
-                result.add( 
-                    key.substring( 
-                        prefix.length(  ), key.length(  ) - suffix.length(  ) ) );
+                result.add( cs.get( key ) );
             }
         }
 
         return (String[])result.toArray( new String[result.size(  )] );
     }
 
-    protected void grabOne( 
+    protected static String[] getCountryCodes(  )
+    {
+        List result = new ArrayList(  );
+
+        Map<String, String> cs = getCommands(  );
+
+        Iterator it = cs.keySet(  ).iterator(  );
+
+        while( it.hasNext(  ) )
+        {
+            String key = (String)it.next(  );
+
+            if( 
+                key.startsWith( REGION_PREFIX )
+                    && key.endsWith( GRABBER_SUFFIX ) )
+            {
+                result.add( 
+                    key.substring( 
+                        REGION_PREFIX.length(  ),
+                        key.length(  ) - GRABBER_SUFFIX.length(  ) ) );
+            }
+        }
+
+        return (String[])result.toArray( new String[result.size(  )] );
+    }
+
+    protected int grabOne( 
         final IStoragePipe storage, final XMLTVConfig.ModuleInfo moduleInfo,
         final IProgress progress, final ILogger logger )
         throws Exception
     {
+        final File xmltvConfigDir =
+            new File( 
+                Application.getInstance(  ).getWorkingDirectory(  ), DIR_CONFIG );
+
         progress.setProgressMessage( 
             Application.getInstance(  ).getLocalizedMessage( "downloading" ) );
 
@@ -264,7 +403,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
         if( cmd == null )
         {
-            cmd = getCommand( moduleInfo.moduleName, "run" );
+            cmd = getCommand( moduleInfo.moduleName, RUN_KEY_SUFFIX );
 
         }
 
@@ -274,24 +413,31 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
                        .severe( 
                 "Command not defined for " + moduleInfo.moduleName );
 
-            logger.error( "Command not defined for " + moduleInfo.moduleName );
+            logger.error( 
+                MessageFormat.format( 
+                    i18n.getString( "Message.CommandNotDefined" ),
+                    moduleInfo.moduleName ) );
 
-            return;
+            return -1;
 
         }
 
         cmd = StringHelper.replaceAll( 
-                cmd, "%config_file%",
-                Application.getInstance(  ).getWorkingDirectory(  )
-                + "/xmltv-configs/" + moduleInfo.configFileName );
+                cmd, REPLACE_CONFIG,
+                new File( xmltvConfigDir, moduleInfo.configFileName )
+                .getAbsolutePath(  ) );
+
         cmd = StringHelper.replaceAll( 
-                cmd, "%xmltv_path%",
-                Application.getInstance(  ).getInstallDirectory(  ) + "/xmltv" );
+                cmd, REPLACE_XMLTV,
+                new File( 
+                    Application.getInstance(  ).getWorkingDirectory(  ),
+                    DIR_INSTALLED ).getAbsolutePath(  ) );
 
         Application.getInstance(  ).getLogger(  ).finest( 
             "Run command: " + cmd );
 
-        logger.info( "Running command: " + cmd );
+        logger.info( 
+            MessageFormat.format( i18n.getString( "Message.Command" ), cmd ) );
 
         int resultCode =
             execGrabCmd( storage, Utils.parseCommand( cmd ), progress, logger );
@@ -299,7 +445,11 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
         Application.getInstance(  ).getLogger(  )
                    .finest( "Result code = " + resultCode );
 
-        logger.info( "Result code = " + resultCode );
+        logger.info( 
+            MessageFormat.format( 
+                i18n.getString( "Message.ResultCode" ), resultCode ) );
+
+        return resultCode;
     }
 
     protected int execGrabCmd( 
@@ -363,18 +513,16 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             {
                 JOptionPane.showMessageDialog( 
                     Application.getInstance(  ).getApplicationFrame(  ),
-                    getLocalizer(  ).getLocalizedMessage( 
-                        "ErrorBox.Text.Linux" ),
-                    getLocalizer(  ).getLocalizedMessage( "ErrorBox.Title" ),
+                    i18n.getString( "ErrorBox.Text.Linux" ),
+                    i18n.getString( "ErrorBox.Title" ),
                     JOptionPane.ERROR_MESSAGE );
             }
             else
             {
                 JOptionPane.showMessageDialog( 
                     Application.getInstance(  ).getApplicationFrame(  ),
-                    getLocalizer(  )
-                        .getLocalizedMessage( "ErrorBox.Text.Windows" ),
-                    getLocalizer(  ).getLocalizedMessage( "ErrorBox.Title" ),
+                    i18n.getString( "ErrorBox.Text.Windows" ),
+                    i18n.getString( "ErrorBox.Title" ),
                     JOptionPane.ERROR_MESSAGE );
             }
 
@@ -399,15 +547,30 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
      * @param args command line for run
      *
      * @return true if exists
-     *
-     * @throws IOException
      */
-    protected boolean checkXmltvExists( final String[] args )
-        throws IOException
+    protected synchronized boolean checkXmltvExists( final String[] args )
     {
         if( ( args == null ) || ( args.length == 0 ) )
         {
-            throw new IOException( "Invalid command line" );
+            return false;
+        }
+
+        if( !Application.getInstance(  ).isUnix(  ) )
+        {
+            final File xmltvDir =
+                new File( 
+                    Application.getInstance(  ).getWorkingDirectory(  ),
+                    DIR_INSTALLED );
+
+            if( !xmltvDir.exists(  ) )
+            {
+                if( 
+                    !FileHelper.unpackFiles( 
+                            PACKAGE_XMLTVWIN_LIST, PACKAGE_XMLTVWIN, xmltvDir ) )
+                {
+                    return false;
+                }
+            }
         }
 
         final String xmltvName = args[0];
@@ -421,7 +584,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
         try
         {
-            path = System.getenv( "PATH" );
+            path = System.getenv( ENV_PATH );
 
         }
         catch( Error ex )
@@ -501,10 +664,11 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
         XMLTVConfig.ModuleInfo info = new XMLTVConfig.ModuleInfo(  );
         info.moduleName = (String)getCommands(  )
                                       .get( 
-                "region." + regionName + ".grabber" );
+                REGION_PREFIX + regionName + GRABBER_SUFFIX );
         info.configFileName = (String)getCommands(  )
                                           .get( 
-                "region." + regionName + ".grabber" ) + ".conf";
+                REGION_PREFIX + regionName + GRABBER_SUFFIX )
+            + SUFFIX_FILE_CONFIG;
 
         synchronized( config.modules )
         {
@@ -545,17 +709,32 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
     {
         if( countryInfos == null )
         {
-            String[] mods = getMods( "region.", ".grabber" );
-            countryInfos = new CountryInfo[mods.length];
+            String[] countryCodes = getCountryCodes(  );
+            countryInfos = new CountryInfo[countryCodes.length];
 
-            for( int i = 0; i < mods.length; i++ )
+            for( int i = 0; i < countryCodes.length; i++ )
             {
+                Map<String, String> cmds = getCommands(  );
+                String regionPlusCode = REGION_PREFIX + countryCodes[i];
+
+                String displayName = null;
+
+                if( cmds.containsKey( regionPlusCode + DISPLAY_NAME_SUFFIX ) )
+                {
+                    displayName = cmds.get( 
+                            regionPlusCode + DISPLAY_NAME_SUFFIX );
+                }
+
+                boolean allowChannelsSelect = true;
+
+                if( cmds.containsKey( regionPlusCode + CHANNEL_SELECT_SUFFIX ) )
+                {
+                    allowChannelsSelect = Boolean.parseBoolean( 
+                            cmds.get( regionPlusCode + CHANNEL_SELECT_SUFFIX ) );
+                }
+
                 countryInfos[i] = new CountryInfo( 
-                        mods[i], 0,
-                        "true".equalsIgnoreCase( 
-                            (String)getCommands(  )
-                                        .get( 
-                                "region." + mods[i] + ".allowChannelsSelect" ) ) );
+                        countryCodes[i], displayName, 0, allowChannelsSelect );
             }
         }
 
@@ -569,7 +748,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
 /**
          * Creates a new ReadProcess object.
-         * 
+         *
          * @param stream
          *            DOCUMENT ME!
          * @param level
@@ -612,7 +791,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
 /**
          * Creates a new Read object.
-         * 
+         *
          * @param rd
          *            DOCUMENT ME!
          * @param logger
@@ -660,7 +839,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
 /**
          * Creates a new ReadOutputData object.
-         * 
+         *
          * @param storage
          *            DOCUMENT ME!
          * @param in
@@ -691,10 +870,8 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
                         if( ( count % 10 ) == 0 )
                         {
                             progress.setProgressMessage( 
-                                getLocalizer(  )
-                                    .getLocalizedMessage( 
-                                    "Message.Count",
-                                    new Object[] { new Integer( count ) } ) );
+                                MessageFormat.format( 
+                                    i18n.getString( "Message.Count" ), count ) );
                         }
                     }
                 };
@@ -702,7 +879,8 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             try
             {
                 new XMLTVImport(  ).process( 
-                    in, storage, callback, new XMLTVImport.Filter(  ), "xmltv/" );
+                    in, storage, callback, new XMLTVImport.Filter(  ),
+                    CHANNEL_PREFIX );
             }
             catch( SAXException ex )
             {
@@ -710,7 +888,9 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
                 {
                     String msg = ex.getException(  ).getMessage(  );
 
-                    logger.error( "SAX Error executing grabber: " + msg );
+                    logger.error( 
+                        MessageFormat.format( 
+                            i18n.getString( "Message.ExecuteError" ), msg ) );
 
                     Application.getInstance(  ).getLogger(  )
                                .log( 
@@ -723,7 +903,8 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
                 String msg = ex.getMessage(  );
 
                 logger.error( 
-                    "ParserConfigurationException executing grabber: " + msg );
+                    MessageFormat.format( 
+                        i18n.getString( "Message.ExecuteError" ), msg ) );
 
                 Application.getInstance(  ).getLogger(  )
                            .log( 
@@ -735,7 +916,9 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             {
                 String msg = ex.getMessage(  );
 
-                logger.error( "Error executing grabber: " + msg );
+                logger.error( 
+                    MessageFormat.format( 
+                        i18n.getString( "Message.ExecuteError" ), msg ) );
 
                 Application.getInstance(  ).getLogger(  )
                            .log( 
