@@ -2,6 +2,8 @@ package freeguide.plugins.program.freeguide.migration;
 
 import freeguide.common.lib.general.StringHelper;
 
+import freeguide.plugins.program.freeguide.FreeGuide;
+
 import java.util.Map;
 import java.util.prefs.BackingStoreException;
 
@@ -43,6 +45,8 @@ public class Migrate0_10_2To0_10_3 extends MigrationProcessBase
      */
     public void migrate(  ) throws Exception
     {
+        FreeGuide.log.info( "Upgrading preferences 0.10.2 -> 0.10.3" );
+
         String browserCommand = getAndRemoveKey( "browserCommand" );
         browserCommand = StringHelper.replaceAll( 
                 browserCommand, "file://%filename%", "%url%" );
