@@ -3,7 +3,6 @@ package freeguide.plugins.program.freeguide.viewer;
 import freeguide.common.lib.fgspecific.Application;
 import freeguide.common.lib.fgspecific.data.TVChannelsSet;
 import freeguide.common.lib.fgspecific.data.TVData;
-import freeguide.common.lib.general.LanguageHelper;
 import freeguide.common.lib.general.Utils;
 
 import freeguide.common.plugininterfaces.BaseModule;
@@ -21,18 +20,24 @@ import freeguide.plugins.program.freeguide.lib.fgspecific.GrabberController;
 import freeguide.plugins.program.freeguide.lib.fgspecific.PluginInfo;
 import freeguide.plugins.program.freeguide.lib.fgspecific.PluginsManager;
 import freeguide.plugins.program.freeguide.lib.fgspecific.StoragePipe;
+import freeguide.plugins.program.freeguide.lib.fgspecific.VersionCheckerThread;
 import freeguide.plugins.program.freeguide.lib.general.LookAndFeelManager;
 
 import java.awt.BorderLayout;
 import java.awt.Dimension;
 import java.awt.Rectangle;
 import java.awt.Toolkit;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
 
+import java.text.MessageFormat;
+
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
+import java.util.ResourceBundle;
 import java.util.Set;
 import java.util.TimeZone;
 import java.util.TreeSet;
@@ -94,25 +99,11 @@ public class MainController extends BaseModule implements IApplication
     /**
      * DOCUMENT_ME!
      *
-     * @return DOCUMENT_ME!
-     *
      * @throws Exception DOCUMENT_ME!
      */
-    public Locale[] getSuppotedLocales(  ) throws Exception
+    public void reloadResourceBundle(  ) throws Exception
     {
-        return LanguageHelper.getLocaleList( "resources/i18n/MessagesBundle" );
-    }
-
-    /**
-     * DOCUMENT_ME!
-     *
-     * @param locale DOCUMENT_ME!
-     *
-     * @throws Exception DOCUMENT_ME!
-     */
-    public void setLocale( Locale locale ) throws Exception
-    {
-        i18n = new LanguageHelper( "resources/i18n/MessagesBundle", locale );
+        i18n = ResourceBundle.getBundle( "resources/i18n/MessagesBundle" );
     }
 
     /**
@@ -124,7 +115,22 @@ public class MainController extends BaseModule implements IApplication
      */
     public String getLocalizedMessage( String key )
     {
-        return i18n.getLocalizedMessage( key );
+        String ans;
+
+        try
+        {
+            ans = i18n.getString( key );
+        }
+        catch( java.util.MissingResourceException e )
+        {
+            FreeGuide.log.log( 
+                Level.WARNING,
+                "Unable to find translatable string for key '" + key + "'." );
+
+            ans = key;
+        }
+
+        return ans;
     }
 
     /**
@@ -137,7 +143,7 @@ public class MainController extends BaseModule implements IApplication
      */
     public String getLocalizedMessage( String key, Object[] params )
     {
-        return i18n.getLocalizedMessage( key, params );
+        return MessageFormat.format( getLocalizedMessage( key ), params );
     }
 
     /**
@@ -179,6 +185,8 @@ public class MainController extends BaseModule implements IApplication
         mainFrame.setTitle( 
             "FreeGuide " + Application.VERSION.getDotFormat(  ) );
 
+        setLookAndFeel(  );
+
         new MenuHandler( this );
 
         mainFrame.getContentPane(  )
@@ -196,29 +204,13 @@ public class MainController extends BaseModule implements IApplication
                     System.exit( 0 );
                 }
             } );
-        mainFrame.getProgressBar(  ).addMouseListener( 
-            new MouseListener(  )
+        mainFrame.getForegroundButton(  ).addActionListener( 
+            new ActionListener(  )
             {
-                public void mouseClicked( MouseEvent e )
+                public void actionPerformed( ActionEvent e )
                 {
                     doShowGrabbers(  );
                 }
-
-                public void mouseEntered( MouseEvent e )
-                {
-                }
-
-                public void mouseExited( MouseEvent e )
-                {
-                }
-
-                public void mousePressed( MouseEvent e )
-                {
-                }
-
-                public void mouseReleased( MouseEvent e )
-                {
-                }
             } );
 
         if( grabberFromWizard != null )
@@ -226,8 +218,6 @@ public class MainController extends BaseModule implements IApplication
             config.activeGrabberIDs.add( grabberFromWizard );
         }
 
-        setLookAndFeel(  );
-
         mainFrame.pack(  );
 
         mainFrame.setBounds( config.ui.mainWindowPosition );
@@ -242,6 +232,12 @@ public class MainController extends BaseModule implements IApplication
 
         applicationFrame = mainFrame;
 
+        // Check the FreeGuide version
+        if( !"no".equals( FreeGuide.config.privacyInfo ) )
+        {
+            new VersionCheckerThread( getApplicationFrame(  ) ).start(  );
+        }
+
         //checkForNoData(  );
         mainFrame.waitForClose(  );
 
@@ -432,7 +428,10 @@ public class MainController extends BaseModule implements IApplication
             {
                 UIManager.setLookAndFeel( inspectedLFClassName );
 
-                SwingUtilities.updateComponentTreeUI( mainFrame );
+                if( mainFrame != null )
+                {
+                    SwingUtilities.updateComponentTreeUI( mainFrame );
+                }
             }
             catch( Exception ex )
             {
@@ -666,11 +665,35 @@ public class MainController extends BaseModule implements IApplication
         mainFrame.dispose(  );
     }
 
+    /**
+     * DOCUMENT_ME!
+     *
+     * @return DOCUMENT_ME!
+     */
+    public Locale[] getSupportedLocales(  )
+    {
+        final List result = new ArrayList(  );
+        Locale[] all = Locale.getAvailableLocales(  );
+
+        for( int i = 0; i < all.length; i++ )
+        {
+            if( 
+                ResourceBundle.getBundle( 
+                        "resources/i18n/MessagesBundle", all[i] ).getLocale(  )
+                                  .equals( all[i] ) )
+            {
+                result.add( all[i] );
+            }
+        }
+
+        return (Locale[])result.toArray( new Locale[result.size(  )] );
+    }
+
     /**
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1441 $
+     * @version $Revision: 1649 $
      */
     public static class Config
     {
@@ -696,7 +719,7 @@ public class MainController extends BaseModule implements IApplication
          * DOCUMENT ME!
          *
          * @author $author$
-         * @version $Revision: 1441 $
+         * @version $Revision: 1649 $
          */
         public static class UI
         {
