@@ -126,7 +126,7 @@ public class HorizontalViewer extends BaseModule implements IModuleViewer
     protected JLabelProgramme currentProgrammeLabel;
 
     /** Menu item for searching through programmes */
-    final JMenuItem menuSearch = new JMenuItem(  );
+    JMenuItem menuSearch = null;
     private boolean alreadyAskedForLoadData = false;
 
     /**
@@ -214,18 +214,15 @@ public class HorizontalViewer extends BaseModule implements IModuleViewer
     /**
      * Set locale handler.
      *
-     * @param locale new locale
-     *
      * @throws Exception
      */
-    public void setLocale( Locale locale ) throws Exception
+    public void reloadResourceBundle(  ) throws Exception
     {
-        super.setLocale( locale );
-        comboBoxDateFormat = DateFormat.getDateInstance( 
-                DateFormat.MEDIUM, locale );
-        htmlDateFormat = DateFormat.getDateInstance( DateFormat.LONG, locale );
-        weekdayFormat = new SimpleDateFormat( "EEEE", locale );
-        shortWeekdayFormat = new SimpleDateFormat( "EE", locale );
+        super.reloadResourceBundle(  );
+        comboBoxDateFormat = DateFormat.getDateInstance( DateFormat.MEDIUM );
+        htmlDateFormat = DateFormat.getDateInstance( DateFormat.LONG );
+        weekdayFormat = new SimpleDateFormat( "EEEE" );
+        shortWeekdayFormat = new SimpleDateFormat( "EE" );
     }
 
     /**
@@ -237,6 +234,11 @@ public class HorizontalViewer extends BaseModule implements IModuleViewer
     {
         if( panel == null )
         {
+            if( this.menuSearch == null )
+            {
+                this.menuSearch = new JMenuItem(  );
+            }
+
             panel = new ViewerFrame( this );
         }
 
@@ -758,8 +760,7 @@ public class HorizontalViewer extends BaseModule implements IModuleViewer
 
         // Add the "All Channels" item
         panel.getComboChannelsSet(  )
-             .insertItemAt( 
-            getLocalizer(  ).getLocalizedMessage( "all_channels" ), 0 );
+             .insertItemAt( getLocalizer(  ).getString( "all_channels" ), 0 );
 
         for( 
             int i = 0;
@@ -775,8 +776,7 @@ public class HorizontalViewer extends BaseModule implements IModuleViewer
         }
 
         panel.getComboChannelsSet(  )
-             .addItem( 
-            getLocalizer(  ).getLocalizedMessage( "edit_channels_sets" ) );
+             .addItem( getLocalizer(  ).getString( "edit_channels_sets" ) );
 
         TVChannelsSet cs =
             getChannelsSetByName( config.currentChannelSetName );
@@ -950,8 +950,7 @@ public class HorizontalViewer extends BaseModule implements IModuleViewer
 
                 public String getDescription(  )
                 {
-                    return getLocalizer(  )
-                               .getLocalizedMessage( "images_gif_jpeg_png" );
+                    return getLocalizer(  ).getString( "images_gif_jpeg_png" );
 
                 }
             } );
